@@ -17,7 +17,6 @@ class ImageBox:
     left_up_y_percentage: float
     right_bottom_x_percentage: float
     right_bottom_y_percentage: float
-    filled_percent: float
 
     @property
     def box_area_percent(self) -> float:
@@ -26,10 +25,6 @@ class ImageBox:
                 * (self.right_bottom_y_percentage - self.left_up_y_percentage)
         )
 
-    @property
-    def image_detection_percent(self) -> float:
-        return self.filled_percent * self.box_area_percent
-
     def get_intersection_box(self, other: 'ImageBox') -> Optional['ImageBox']:
         left = max(self.left_up_x_percentage, other.left_up_x_percentage)
         top = max(self.left_up_y_percentage, other.left_up_y_percentage)
@@ -46,7 +41,6 @@ class ImageBox:
                 left_up_x_percentage=left,
                 left_up_y_percentage=top,
                 right_bottom_x_percentage=right,
-                right_bottom_y_percentage=bottom,
-                filled_percent=other.filled_percent
+                right_bottom_y_percentage=bottom
             )
             return intersection_box
